
#ifndef GDHCPD_create_scope_set_entries_H
#   define GDHCPD_create_scope_set_entries_H

extern struct w *widgets;

void create_scope_set_entries(struct w *widgets);

GtkWidget *make_scope_entry_with_label(GtkTable *table,
				 const gchar *label_text,
				 gint left_attach,
				 gint right_attach,
				 gint top_attach,
				 gint bottom_attach,
				 gint entry_length);
#endif
